..
    Developer note: the files in the generated folder are generated by the file
    `sphinx_dd_extension/autodoc.py`.


Common IDS structures reference
===============================

.. toctree::
    :name: dd-reference-toc-util
    :glob:
    :maxdepth: 1

    generated/util/*
